VolumeFadeStep class

Represents a step in a volume fade sequence.

Annotations
  • @JsonSerializable.new()

Constructors

VolumeFadeStep(Duration time, double volume)
Creates a new volume fade step.
VolumeFadeStep.fromJson(Map<String, dynamic> json)
Converts JSON object to VolumeFadeStep.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
time → Duration
The time at which the volume should be set to volume.
final
volume → double
The volume level to set at time.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts the VolumeFadeStep instance to a JSON object.
toString() → String
A string representation of this object.
inherited
toWire() → VolumeFadeStepWire
Converts to wire datatype which is used for host platform communication.

Operators

operator ==(Object other) → bool
The equality operator.
inherited