AlarmSet class

A set of alarms where uniqueness is determined by the AlarmSettings.id.

Constructors

AlarmSet(Iterable<AlarmSettings> alarms)
Constructs an instance of AlarmSet using the given alarms.
AlarmSet.empty()
Empty AlarmSet.

Properties

alarms → Set<AlarmSettings>
Returns the set of alarms.
no setter
hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

add(AlarmSettings alarm) → AlarmSet
Returns a new AlarmSet with the given alarm added.
contains(AlarmSettings alarm) → bool
Returns true if the set contains the given alarm.
containsId(int alarmId) → bool
Returns true if the set contains an alarm with the given alarmId.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(AlarmSettings alarm) → AlarmSet
Returns a new AlarmSet with the given alarm removed.
removeById(int alarmId) → AlarmSet
Returns a new AlarmSet with the given alarmId removed.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited