AlarmMoved class final
The alarm is still owed, and now rings at nextRingAt.
- Inheritance
-
- Object
- AlarmEvent
- AlarmMoved
Constructors
- AlarmMoved({required int id, required AlarmEventCause cause, required DateTime recordedAt, required DateTime nextRingAt})
-
Creates an AlarmMoved.
const
Properties
- cause → AlarmEventCause
-
Why the host did it.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
Id of the alarm this happened to.
finalinherited
- nextRingAt → DateTime
-
When the alarm rings now.
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- recordedAt → DateTime
-
When the host recorded this, which may be well before it was delivered.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited